# iQEditors
Библиотека с текстовыми редакторами, используемых в проектах [iQStudio](https://gitflic.ru/team/iqstudio):

 - iQMemo
 - iQNote
 - iQBooks
 - iQRecipe
 - iQ Programming CookBook

# Состав
 - iQEditor - простой редактор форматированного текста
 - iQNoteEditor - редактор записок с поддержкой подсветки блоков кода

# Установка
``` bash
pip install iqEditors
```

# Примеры использования 
Общий пример (относительено сложный) взаимодействия нескольких виждетов:
```
__main__.py
```
Примеры прямого использования в папке `examples`. 

# Лицензия
GPL v3
